##
##  gsl.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         gsl
Summary:      GNU Scientific Library
URL:          http://sources.redhat.com/gsl/
Vendor:       Mark Galassi et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Algorithm
License:      GPL
Version:      2.8
Release:      20240526

#   list of sources
Source0:      ftp://ftp.gnu.org/pub/gnu/gsl/gsl-%{version}.tar.gz
Patch0:       gsl.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101

%description
    The GNU Scientific Library (GSL) is a numerical library for C and
    C++ programmers. The library provides a wide range of mathematical
    routines such as random number generators, special functions and
    least-squares fitting. There are over 1000 functions in total.

    The complete range of subject areas covered by the library
    includes, Complex Numbers, Roots of Polynomials, Special Functions,
    Vectors and Matrices, Permutations, Sorting, BLAS Support, Linear
    Algebra, Eigensystems, Fast Fourier Transforms, Quadrature, Random
    Numbers, Quasi-Random Sequences, Random Distributions, Statistics,
    Histograms, N-Tuples, Monte Carlo Integration, Simulated Annealing,
    Differential Equations, Interpolation, Numerical Differentiation,
    Chebyshev Approximation, Series Acceleration, Discrete Hankel
    Transforms, Root-Finding, Minimization, Least-Squares Fitting,
    Physical Constants, IEEE Floating-Point.

%track
    prog gsl = {
        version   = %{version}
        url       = http://ftp.gnu.org/gnu/gsl/
        regex     = gsl-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --infodir=%{l_prefix}/info \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std}

%files -f files

%clean

